==> checkstyle-8.45.1-tests.jar: com/puppycrawl/tools/checkstyle/checks/whitespace/parenpad/InputParenPadLeftRightAndNoSpace2.java <==
/*
ParenPad
option = (default)nospace
tokens = METHOD_CALL


*/

package com.puppycrawl.tools.checkstyle.checks.whitespace.parenpad;

import java.io.IOException;
import java.io.StringWriter;
import java.io.Writer;

public class InputParenPadLeftRightAndNoSpace2
{
    class ParenPadNoSpace  {
        ParenPadNoSpace() {
            this(0);
        }

        ParenPadNoSpace(int i) {
            super();
        }

        @SuppressWarnings("")
        void method(boolean status) {
            try (Writer writer = new StringWriter()) {
                do {
                    writer.append("a");
                } while (status);
            } catch (IOException e) {
                while (status) {
                    for (int i = 0; i < (long) (2 * (4 / 2)); i++) {
                        if (i > 2) {
                            synchronized (this) {
                                switch (i) {
                                    case 3:
                                    case (4):
                                    case 5:
                                        break;
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    class ParenPadSpaceLeft {
        ParenPadSpaceLeft( ) {
            this( 0);
        }

        ParenPadSpaceLeft( int i) {
            super( );
        }

        @SuppressWarnings( "")
        void method( boolean status) {
            try ( Writer writer = new StringWriter( )) {
                do {
                    writer.append("a");
                } while ( status);
            } catch ( IOException e) {
                while ( status) {
                    for ( int i = 0; i < ( long) ( 2 * ( 4 / 2)); i++) {
                        if ( i > 2) {
                            synchronized ( this) {
                                switch ( i) {
                                    case 3:
                                    case ( 4):
                                    case 5:
                                        break;
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    class ParenPadSpaceRight {
        ParenPadSpaceRight( ) {
            this(0 );
        }

        ParenPadSpaceRight(int i ) {
            super( );
        }

        @SuppressWarnings("" )
        void method(boolean status ) {
            try (Writer writer = new StringWriter( ) ) {
                do {
                    writer.append("a" ); // violation
                } while (status );
            } catch (IOException e ) {
                while (status ) {
                    for (int i = 0; i < (long ) (2 * (4 / 2 ) ); i++ ) {
                        if (i > 2 ) {
                            synchronized (this ) {
                                switch (i ) {
                                    case 3:
                                    case (4 ):
                                    case 5:
                                        break;
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    String foo() {
        return ( (Object
                ) bar( ( 1 > 2 ) ?
                        ( ( 3 < 4 )? false : true ) :
                        ( ( 1 == 1 ) ? false : true) ) ).toString();
    }
    @MyAnnotation2
    public boolean bar(boolean a) {
        assert ( true );
        return true;
    }

    boolean fooo = this.bar(( true && false ) && true);
}
@interface MyAnnotation2 {
    String someField( ) default "Hello world";
}

enum MyEnum12 {
    SOME_CONSTANT( ) {
        int i = (int) (2 * (4 / 2)
                );
    };

    public void myMethod() {
        String s = "test";
        Object o = s;
        ((String)o).length();
        ( (String)o ).length();
    }

    public void crisRon() {
        Object leo = "messi";
        Object ibra = leo;
        ((String)leo).compareTo( (String)ibra );
        Math.random();
    }

    public void intStringConv() {
        Object a = 5;
        Object b = "string";
        int w = Integer.parseInt((String)a);
        int x = Integer.parseInt( (String)a);
        double y = Double.parseDouble((String)a );
        float z = Float.parseFloat( (String)a );
        String d = ((String)b);
    }

    public int something( Object o ) {
        if ( o == null || !( o instanceof Float ) ) {
            return -1;
        }
        return Integer.valueOf( 22 ).compareTo( (Integer) o );
    }

    private void launch(Integer number ) {
        String myInt = ( number.toString() + '\0' );
        boolean result = false;
        if (number == 123)
            result = true;
    }

    private static String getterName( Exception t) {
        if (t instanceof ClassNotFoundException ) {
            return ( (ClassNotFoundException) t ).getMessage();
        }
        else {
            return "?";
        }
    }

    private Object exam;

    public String testing() {
        return ( this.exam != null )
                ? ( ( Enum )this.exam ).name()
                : null;
    }

    Object stringReturnValue( Object result ) {
        if ( result instanceof String ) {
            result = ( (String) result ).length();
        }
        return result;
    }



    private void except() {
        java.util.ArrayList<Integer> arrlist = new java.util.ArrayList<Integer>( 5 );
        arrlist.add( 20);
        arrlist.add(15 );
        arrlist.add( 30 );
        arrlist.add(45);
        try {
            ( arrlist ).remove( 2);
        } catch ( IndexOutOfBoundsException x ) {
            x.getMessage();
        }
        org.junit.Assert.assertThat( "123", org.hamcrest.CoreMatchers.is( "123" ) );
        org.junit.Assert.assertThat( "Help! Integers don't work",
                0, org.hamcrest.CoreMatchers.is( 1 ) );
    }
}
enum MyEnum22 {
    SOME_CONSTANT( ) {
        int i = (int) (2 * (4 / 2
)                   );
    };
}

==> checkstyle-9.2-tests.jar: com/puppycrawl/tools/checkstyle/checks/whitespace/parenpad/InputParenPadLeftRightAndNoSpace2.java <==
/*
ParenPad
option = (default)nospace
tokens = METHOD_CALL


*/

package com.puppycrawl.tools.checkstyle.checks.whitespace.parenpad;

import java.io.IOException;
import java.io.StringWriter;
import java.io.Writer;

public class InputParenPadLeftRightAndNoSpace2
{
    class ParenPadNoSpace  {
        ParenPadNoSpace() {
            this(0);
        }

        ParenPadNoSpace(int i) {
            super();
        }

        @SuppressWarnings("")
        void method(boolean status) {
            try (Writer writer = new StringWriter()) {
                do {
                    writer.append("a");
                } while (status);
            } catch (IOException e) {
                while (status) {
                    for (int i = 0; i < (long) (2 * (4 / 2)); i++) {
                        if (i > 2) {
                            synchronized (this) {
                                switch (i) {
                                    case 3:
                                    case (4):
                                    case 5:
                                        break;
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    class ParenPadSpaceLeft {
        ParenPadSpaceLeft( ) {
            this( 0);
        }

        ParenPadSpaceLeft( int i) {
            super( );
        }

        @SuppressWarnings( "")
        void method( boolean status) {
            try ( Writer writer = new StringWriter( )) {
                do {
                    writer.append("a");
                } while ( status);
            } catch ( IOException e) {
                while ( status) {
                    for ( int i = 0; i < ( long) ( 2 * ( 4 / 2)); i++) {
                        if ( i > 2) {
                            synchronized ( this) {
                                switch ( i) {
                                    case 3:
                                    case ( 4):
                                    case 5:
                                        break;
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    class ParenPadSpaceRight {
        ParenPadSpaceRight( ) {
            this(0 );
        }

        ParenPadSpaceRight(int i ) {
            super( );
        }

        @SuppressWarnings("" )
        void method(boolean status ) {
            try (Writer writer = new StringWriter( ) ) {
                do {
                    writer.append("a" ); // violation
                } while (status );
            } catch (IOException e ) {
                while (status ) {
                    for (int i = 0; i < (long ) (2 * (4 / 2 ) ); i++ ) {
                        if (i > 2 ) {
                            synchronized (this ) {
                                switch (i ) {
                                    case 3:
                                    case (4 ):
                                    case 5:
                                        break;
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    String foo() {
        return ( (Object
                ) bar( ( 1 > 2 ) ? // violation
                        ( ( 3 < 4 )? false : true ) :
                        ( ( 1 == 1 ) ? false : true) ) ).toString(); // violation
    }
    @MyAnnotation2
    public boolean bar(boolean a) {
        assert ( true );
        return true;
    }

    boolean fooo = this.bar(( true && false ) && true);
}
@interface MyAnnotation2 {
    String someField( ) default "Hello world";
}

enum MyEnum12 {
    SOME_CONSTANT( ) {
        int i = (int) (2 * (4 / 2)
                );
    };

    public void myMethod() {
        String s = "test";
        Object o = s;
        ((String)o).length();
        ( (String)o ).length();
    }

    public void crisRon() {
        Object leo = "messi";
        Object ibra = leo;
        ((String)leo).compareTo( (String)ibra ); // 2 violations
        Math.random();
    }

    public void intStringConv() {
        Object a = 5;
        Object b = "string";
        int w = Integer.parseInt((String)a);
        int x = Integer.parseInt( (String)a); // violation
        double y = Double.parseDouble((String)a ); // violation
        float z = Float.parseFloat( (String)a ); // 2 violations
        String d = ((String)b);
    }

    public int something( Object o ) {
        if ( o == null || !( o instanceof Float ) ) {
            return -1;
        }
        return Integer.valueOf( 22 ).compareTo( (Integer) o ); // 4 violations
    }

    private void launch(Integer number ) {
        String myInt = ( number.toString() + '\0' );
        boolean result = false;
        if (number == 123)
            result = true;
    }

    private static String getterName( Exception t) {
        if (t instanceof ClassNotFoundException ) {
            return ( (ClassNotFoundException) t ).getMessage();
        }
        else {
            return "?";
        }
    }

    private Object exam;

    public String testing() {
        return ( this.exam != null )
                ? ( ( Enum )this.exam ).name()
                : null;
    }

    Object stringReturnValue( Object result ) {
        if ( result instanceof String ) {
            result = ( (String) result ).length();
        }
        return result;
    }



    private void except() {
        java.util.ArrayList<Integer> arrlist = new java.util.ArrayList<Integer>( 5 );
        arrlist.add( 20); // violation
        arrlist.add(15 ); // violation
        arrlist.add( 30 ); // 2 violations
        arrlist.add(45);
        try {
            ( arrlist ).remove( 2); // violation
        } catch ( IndexOutOfBoundsException x ) {
            x.getMessage();
        }
        org.junit.Assert.assertThat( "123", org.hamcrest.CoreMatchers.is( "123" ) ); // 4 violations
        org.junit.Assert.assertThat( "Help! Integers don't work", // violation
                0, org.hamcrest.CoreMatchers.is( 1 ) ); // 3 violations
    }
}
enum MyEnum22 {
    SOME_CONSTANT( ) {
        int i = (int) (2 * (4 / 2
)                   );
    };
}
